Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Slice ¶
type Slice[T any] []T
Slice is a wrapper around a Go's built-in slice type. It provides a couple of helper functions that make it easier to satisfy interfaces such as sort.Interface and heap.Interface.
Click to show internal directories.
Click to hide internal directories.